@@ -8,11 +8,19 @@
 //!
 //! These endpoints are used for querying group members.
 
+mod add;
 mod member;
 mod members;
+mod remove;
+
+pub use self::add::AddGroupMember;
+pub use self::add::AddGroupMemberBuilder;
 
 pub use self::member::GroupMember;
 pub use self::member::GroupMemberBuilder;
 
 pub use self::members::GroupMembers;
 pub use self::members::GroupMembersBuilder;
+
+pub use self::remove::RemoveGroupMember;
+pub use self::remove::RemoveGroupMemberBuilder;
